# Workflow Plan Template

Use this template when creating workflow plans in step-07-workflows.md

## Template Structure

Copy the content from step-07-workflows.md when creating workflow plans. The template is embedded in the step file as a code block under "Workflow plan template".

## Usage

1. Navigate to the workflow folder
2. Create workflow-plan.md
3. Use the template structure from step-07-workflows.md
4. Fill in details specific to your workflow

## Required Sections

- Purpose
- Requirements (User Inputs, Prerequisites, Dependencies)
- Proposed Steps
- Expected Outputs
- Integration Points
- Implementation Notes
